get_siconv() is the package's workhorse. It downloads, cleans, and
returns one of the several datasets maintained by Plataforma +Brasil on federal
targeted transfers in Brazil. Under the hoods, the function handles GET requests,
downloads and stores intermediary files, and reads as fast as possible the data
to a tibble format convenient for use in analysis.
get_siconv(dataset = NULL, encoding = "UTF-8", cache = TRUE, verbose = TRUE)A string indicating the dataset to retrieve. Valid options:
"programas" -- data on available programs maintained by the Federal Government;
"programas_propostas" -- keys to match programs and proposals submitted to the Federal Government;
"propostas" -- data on proposals submitted to the Federal Government;
"convenios" -- data on proposals effectively accepted situation and amount transferred by the Federal Government;
"emendas" -- data on federal budget amendments made by Brazilian Federal Deputies and Senators, amount transferred and the transference recipient;
"planos" -- data on application plans submitted to the Federal Government. This document includes all goods, services and works required by the covenant to accomplish the project;
"empenhos" -- data on transfers which the Federal Government has reserved its budget to pay the covenant when the project ends;
"desembolsos" -- data on transfers disbursements by the Federal Government;
"obtv" -- data on payments made to local suppliers and contractors hired to execute funded projects;
"historico" -- proposals' track record;
"ingresso_contrapartida" -- record of counterpart payments;
"aditivos" -- data on contracts' budget addendum;
"crono_metas" -- project's goals timeline;
"cronogramas" -- project's execution timeline;
"consorcios" -- data on proposals where multiple local governments or private entities cooperate to request federal resources;
"empenhos_desembolsos" -- keys to match appropriations and disbursements by Federal Government;
"proponentes" -- data on proposals' proponents;
"cronograma_desembolsos" -- project's transfers disbursements timeline;
"justificativas" -- proposals' justifications;
When not specified, dataset defaults to "programas".
Encoding used to read raw files. Defaults to "UTF-8", but users might need to change this option to other valid options (e.g., "latin1") if data are returned with uncommon characters.
Should the function maintain a local copy of the data? To save
both time and SICONV's server resources, this defaults to TRUE. Data is
stored as a zipfile in the foleer "cache" in the working directory (avoid
changing files' names inside this folder).
Should the function display messages and progress bar? Defaults
to TRUE.
A tibble contantaining the requested data as defined in the
dataset argument. Use the show_schema function to get detailed information
on available variables and information.
# NOT RUN {
df <- get_siconv(dataset = "propostas")
# }
Run the code above in your browser using DataLab